/*
 * Java
 *
 * Copyright 2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.giml.cssgenerator.selector;

import java.io.StringWriter;
import java.util.Hashtable;
import java.util.Map;

import org.w3c.css.sac.AttributeCondition;
import org.w3c.css.sac.Condition;

import com.steadystate.css.parser.selectors.ClassConditionImpl;

/**
 *
 */
public class ClassSelector implements Selector {

	private static final String CLASS_SELECTOR_VAR_PREFIX = "class_";
	private final Map<String, String> classSelectorVars = new Hashtable<String, String>();

	@Override
	public String generate(Condition c, StringWriter writer) throws IllegalArgumentException {
		AttributeCondition condition = this.get(c);
		String value = condition.getValue();
		String classSelectorVar = this.classSelectorVars.get(value);
		if (classSelectorVar != null) {
			return classSelectorVar;
		}
		StringBuilder classSelectorVarSb = new StringBuilder(CLASS_SELECTOR_VAR_PREFIX).append(value);
		writer.append(this.getClassName()).append(" ").append(classSelectorVarSb);
		writer.append(" = new ");
		writer.append(this.getClassName()).append("(\"");
		writer.append(value);
		writer.append("\");\n");
		this.classSelectorVars.put(value, classSelectorVarSb.toString());
		return classSelectorVarSb.toString();
	}

	private AttributeCondition get(Condition condition) {
		if (!this.matches(condition)) {
			throw new IllegalArgumentException("Given condition is not an AttributeCondition");
		}
		return (AttributeCondition) condition;
	}

	@Override
	public boolean matches(Condition condition) {
		return condition instanceof ClassConditionImpl;
	}

	@Override
	public String getClassName() {
		return "ej.style.selector.ClassSelector";
	}

	@Override
	public String generate(org.w3c.css.sac.Selector s, StringWriter writer) throws IllegalArgumentException {
		throw new RuntimeException();
	}

	@Override
	public boolean matches(org.w3c.css.sac.Selector selector) {
		return false;
	}

}
