/*
 * Java
 *
 * Copyright 2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.giml.description;

import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.ServiceLoader;
import java.util.Set;

/**
 *
 */
public class DescriptionFactory {

	private static final Map<String, Description> DESCRIPTIONS;

	static {
		DESCRIPTIONS = new HashMap<>();
		ServiceLoader<DescriptionPackage> serviceLoader = ServiceLoader.load(DescriptionPackage.class);
		for (Iterator<DescriptionPackage> iterator = serviceLoader.iterator(); iterator.hasNext();) {
			DescriptionPackage descriptionPackage = iterator.next();
			descriptionPackage.loadDescriptions();
		}
	}

	private DescriptionFactory() {
		// Hide utility class constructor.
	}

	public static final Description addDescription(String tag, Description description) {
		return DESCRIPTIONS.put(tag.toLowerCase(), description);
	}

	/**
	 * Clears all the descriptions.
	 */
	public static final void clearDescriptions() {
		DESCRIPTIONS.clear();
	}

	public static final Description getDescription(String tag) {
		return DESCRIPTIONS.get(tag.toLowerCase());
	}

	public static final Set<String> getTags() {
		return DESCRIPTIONS.keySet();
	}

	public static final Set<String> getAllTags() {
		Set<String> result = new HashSet<>();
		Set<String> keys = DESCRIPTIONS.keySet();
		result.addAll(keys);
		for (Description description : DESCRIPTIONS.values()) {
			result.addAll(description.getElements());
		}
		return result;
	}

}
