/*
 * Java
 *
 * Copyright 2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.giml.description;

import java.io.StringWriter;

/**
 * The interface {@code StyleDeclaration} represents a complete style declaration.
 *
 * A style declaration is composed of:
 * <ul>
 * <li>an unique style sheet declaration,</li>
 * <li>multiple style initialization.</li>
 * </ul>
 *
 * Example:
 * 
 * <pre>
 * StyleDeclaration declaration = new StyleDeclarationImpl();
 * declaration.generateStyleSheetDeclaration("styleSheet");
 * declaration.generateStyleInitialization("myStyle1");
 * declaration.generateStyleInitialization("myStyle2");
 * declaration.generateStyleInitialization("myStyle3");
 * </pre>
 */
public interface StyleDeclaration {

	void generateStyleSheetDeclaration(String variableName);

	void generateStyleInitialization(String styleVariableName);

	StringWriter getWriter();
}
