/*
 * Java
 *
 * Copyright 2009-2019 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.is2t.java;


import com.is2t.java.nodes.AddressReference;
import com.is2t.java.nodes.Block;
import com.is2t.java.nodes.BreakStatement;
import com.is2t.java.nodes.CaseEntry;
import com.is2t.java.nodes.CatchClause;
import com.is2t.java.nodes.ClassDeclaration;
import com.is2t.java.nodes.CompilationUnit;
import com.is2t.java.nodes.ComposeFieldOrLocalDeclaration;
import com.is2t.java.nodes.ConstructorDeclaration;
import com.is2t.java.nodes.ContinueStatement;
import com.is2t.java.nodes.DoStatement;
import com.is2t.java.nodes.Expression;
import com.is2t.java.nodes.FieldDeclaration;
import com.is2t.java.nodes.ForStatement;
import com.is2t.java.nodes.IfStatement;
import com.is2t.java.nodes.Initializer;
import com.is2t.java.nodes.InterfaceDeclaration;
import com.is2t.java.nodes.JavadocComment;
import com.is2t.java.nodes.LabelStatement;
import com.is2t.java.nodes.LocalDeclaration;
import com.is2t.java.nodes.MethodDeclaration;
import com.is2t.java.nodes.Modifiers;
import com.is2t.java.nodes.ReturnStatement;
import com.is2t.java.nodes.SemiColonStatement;
import com.is2t.java.nodes.SimpleComment;
import com.is2t.java.nodes.SwitchStatement;
import com.is2t.java.nodes.SynchronizedStatement;
import com.is2t.java.nodes.ThrowStatement;
import com.is2t.java.nodes.TryStatement;
import com.is2t.java.nodes.TypeReference;
import com.is2t.java.nodes.WhileStatement;
import com.is2t.java.nodes.expressions.ArrayAccess;
import com.is2t.java.nodes.expressions.ArrayAllocation;
import com.is2t.java.nodes.expressions.Assignment;
import com.is2t.java.nodes.expressions.BinaryExpression;
import com.is2t.java.nodes.expressions.BooleanLiteral;
import com.is2t.java.nodes.expressions.ByteLiteral;
import com.is2t.java.nodes.expressions.CastExpression;
import com.is2t.java.nodes.expressions.CharLiteral;
import com.is2t.java.nodes.expressions.ClassLiteral;
import com.is2t.java.nodes.expressions.CompoundAssignment;
import com.is2t.java.nodes.expressions.DoubleLiteral;
import com.is2t.java.nodes.expressions.DoubleLiteralInDoubleClass;
import com.is2t.java.nodes.expressions.ExplicitConstructorInvocation;
import com.is2t.java.nodes.expressions.FieldAccess;
import com.is2t.java.nodes.expressions.FloatLiteral;
import com.is2t.java.nodes.expressions.FloatLiteralInFloatClass;
import com.is2t.java.nodes.expressions.IncrementExpression;
import com.is2t.java.nodes.expressions.IntegerLiteral;
import com.is2t.java.nodes.expressions.LocalAccess;
import com.is2t.java.nodes.expressions.LongLiteral;
import com.is2t.java.nodes.expressions.MessageSend;
import com.is2t.java.nodes.expressions.NullLiteral;
import com.is2t.java.nodes.expressions.ObjectAllocation;
import com.is2t.java.nodes.expressions.ShortLiteral;
import com.is2t.java.nodes.expressions.StringLiteral;
import com.is2t.java.nodes.expressions.TernaryExpression;
import com.is2t.java.nodes.expressions.ThisExpression;
import com.is2t.java.nodes.expressions.TypeReferenceExpression;
import com.is2t.java.nodes.expressions.UnaryExpression;


public abstract class JavaSourceGenerator {

	public abstract void generateCompilationUnit(CompilationUnit node);
	public abstract void generateExpression(Expression node);
	public abstract void generateModifiers(Modifiers node);

	public abstract void generateMethodDeclaration(MethodDeclaration node);
	public abstract void generateClassDeclaration(ClassDeclaration node);
	public abstract void generateInterfaceDeclaration(InterfaceDeclaration node);
	public abstract void generateTypeReference(TypeReference node);
	public abstract void generateStructReference(AddressReference node);
	public abstract void generateConstructorDeclaration(ConstructorDeclaration node);
	public abstract void generateSemiColon(SemiColonStatement gen);

	public abstract void generateFieldDeclaration(FieldDeclaration node);
	public abstract void generateInitializerUsing(Initializer initializer);
	public abstract void generateLocalDeclaration(LocalDeclaration node);
	public abstract void generateComposeFieldOrLocalDeclaration( ComposeFieldOrLocalDeclaration node);

	public abstract void generateLocalAccess(LocalAccess node);
	public abstract void generateFieldAccess(FieldAccess node);
	public abstract void generateArrayAccess(ArrayAccess node);

	public abstract void generateJavadocComment(JavadocComment node);
	public abstract void generateSimpleComment(SimpleComment simpleComment);

	public abstract void generateMessageSend(MessageSend node);
	public abstract void generateExplicitConstructorInvocation(ExplicitConstructorInvocation node);
	public abstract void generateBlock(Block node);
	public abstract void generateAssignment(Assignment node);
	public abstract void generateCompoundAssignment(CompoundAssignment node);
	public abstract void generateReturnStatement(ReturnStatement node);
	public abstract void generateCastExpression(CastExpression node);

	public abstract void generateArrayAllocation(ArrayAllocation node);
	public abstract void generateObjectAllocation(ObjectAllocation node);

	public abstract void generateStringLiteral(StringLiteral node);
	public abstract void generateClassLiteral(ClassLiteral node);
	public abstract void generateBooleanLiteral(BooleanLiteral node);
	public abstract void generateNullLiteral(NullLiteral node);
	public abstract void generateIntegerLiteral(IntegerLiteral node);
	public abstract void generateByteLiteral(ByteLiteral node);
	public abstract void generateCharLiteral(CharLiteral node);
	public abstract void generateShortLiteral(ShortLiteral node);
	public abstract void generateFloatLiteral(FloatLiteral node);
	public abstract void generateLongLiteral(LongLiteral node);
	public abstract void generateDoubleLiteral(DoubleLiteral node);
	public abstract void generateDoubleLiteralInDoubleClass(DoubleLiteralInDoubleClass node);
	public abstract void generateFloatLiteralInFloatClass( FloatLiteralInFloatClass node);

	public abstract void generateUnaryExpression(UnaryExpression node);
	public abstract void generateBinaryExpression(BinaryExpression node);
	public abstract void genarateTernaryExpression(TernaryExpression node);
	public abstract void generateIncrementExpression(IncrementExpression node);
	public abstract void generateThisExpression(ThisExpression node);

	public abstract void generateIfStatement(IfStatement node);
	public abstract void generateForStatement(ForStatement node);
	public abstract void generateWhileStatement(WhileStatement node);
	public abstract void generateDoStatement( DoStatement node);
	public abstract void generateSwitchStatement(SwitchStatement node);
	public abstract void generateBreakStatement(BreakStatement node);
	public abstract void generateContinueStatement(ContinueStatement node);
	public abstract void generateLabelStatement(LabelStatement node);
	public abstract void generateCaseSatement( CaseEntry node);

	public abstract void generateCatchClause(CatchClause node);
	public abstract void generateTryStatement(TryStatement node);
	public abstract void generateThrowStatement(ThrowStatement node);
	public abstract void generateSynchronizedStatement(SynchronizedStatement node);

	public abstract void generateTypeReferenceExpression(TypeReferenceExpression typeReferenceExpression);


}