/*
 * Java
 *
 * Copyright 2010-2020 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.is2t.microbsp.microui.geg;

import com.is2t.microbsp.microui.natives.NSystemStates;

import ej.microui.MicroUIPump;
import ej.microui.event.EventHandler;
import ej.microui.event.generator.States;

/**
 * Instance created by SystemMicroUIGenerator
 */
public class SystemStates extends States {

	/**
	 * Driver MicroEJ specific
	 */
	private static final int DRIVER_VALUE_MASK = 0x0000ff00;
	private static final int DRIVER_VALUE_SHIFT = 8;
	private static final int DRIVER_STATE_MASK = 0x000000ff;
	private static final int DRIVER_STATE_SHIFT = 0;

	private boolean haveToInitialize; // false init

	/**
	 * @param nbValues
	 *            see API States
	 * @param initialValues
	 *            see API States
	 */
	public SystemStates(int[] nbValues, int[] initialValues) {
		super(nbValues, initialValues);
	}

	/**
	 * There is no default values; need to get the initial values from native world
	 * 
	 * @param nbValues
	 *            see API States
	 */
	public SystemStates(int[] nbValues) {
		this(nbValues, new int[nbValues.length]/* 0 init */);
		this.haveToInitialize = true;
	}

	@Override
	public int addToSystemPool() {
		int id = super.addToSystemPool();
		if (this.haveToInitialize) {
			for (int i = getNumberOfStates(); --i >= 0;) {
				send(i, NSystemStates.getInitialStateValue(id, i));
			}
			this.haveToInitialize = false;
		}
		return id;
	}

	@Override
	public void convert(MicroUIPump pump, int inputEvent, EventHandler eventHandler) {
		int value = (inputEvent & DRIVER_VALUE_MASK) >>> DRIVER_VALUE_SHIFT;
		int id = (inputEvent & DRIVER_STATE_MASK) >>> DRIVER_STATE_SHIFT;
		send(id, value, eventHandler);
	}
}
